
int
main()
{
	const char *p;

	p = "hello";
	return p[0] - 104;
}
